# Table of Contents

- [application-modernization-scope-applications](<./application-modernization-scope-applications.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Step 2: Scope Applications](<./Step-2-Scope-Applications.md>)
  - [Identify Applications](<./Step-2-Scope-Applications/Identify-Applications.md>)
  - [Save Your Results](<./Step-2-Scope-Applications/Save-Your-Results.md>)
  - [Tag Scoped Applications](<./Step-2-Scope-Applications/Tag-Scoped-Applications.md>)
  - [Was this page helpful?](<./Step-2-Scope-Applications/Was-this-page-helpful.md>)
